@@ -183,17 +183,23 @@ def is_whitelisted(misp_msg: dict, filter_config: List[Dict]):
     attr = misp_msg.get("Attribute", None)
     if not event or not attr:
         return False
-    org_id = event.get("org_id", None)
+    orgc_id = event.get("orgc_id", None)
     intel_type = attr.get("type", None)
     tags = get_tags(attr)
-    if not org_id or not intel_type:
+    if not orgc_id or not intel_type:
         return False
     if not filter_config:
         # no whitelist = allow all
         return True
     for fil in filter_config:
         if (
-            (not fil.get("orgs", None) or org_id in fil["orgs"])
+            (
+                # we check int(org_id) as well because MISP can give us strings
+                # for numeric org IDs
+                not fil.get("orgs", None)
+                or orgc_id in fil["orgs"]
+                or int(orgc_id) in fil["orgs"]
+            )
             and (not fil.get("types", None) or intel_type in fil["types"])
             and (
                 not fil.get("tags", None)
@@ -326,7 +332,7 @@ def stix2_sighting_to_misp(sighting: Sighting):
 
     misp_sighting = pymisp.MISPSighting()
     source = None
-    if "x_threatbus_source" in sighting.object_properties():
+    if "x_threatbus_source" in sighting:
         source = str(sighting.x_threatbus_source)
     misp_sighting.from_dict(
         id=misp_id(sighting.sighting_of_ref),
